@@ -130,7 +130,8 @@ class FlowersDist(nn.Module):
         self.net = None
         self.data_ndim = 3072
         self.data_shape = (3, 32, 32)
-        self._load_ckpt()
+        train_epsilon = 7.5e-3
+        self.inv_temp = 2.0 / train_epsilon ** 2
 
     def _load_ckpt(self):
         import os
@@ -175,7 +176,7 @@ class FlowersDist(nn.Module):
         self.setup_ft()
 
     def forward(self, x):
-        return self.net(x)
+        return self.net(x) * self.inv_temp
 
     def log_prob(self, x):
         return self.forward(x)
@@ -201,6 +202,8 @@ class MNISTDist(FlowersDist):
         super().__init__()
         self.data_ndim = 1024
         self.data_shape = (1, 32, 32)
+        train_epsilon = 7.5e-3
+        self.inv_temp = 2.0 / train_epsilon ** 2
 
     def _load_ckpt(self):
         import os
